@@ -715,7 +715,7 @@ docdb_query.src_sqlite <- function(src, key, query, ...) {
       FROM "/** key **/"
       LIMIT /** n **/ )
     SELECT DISTINCT LTRIM(fullkey, \'$.\') AS flds
-    FROM extracted, json_tree(extracted.json)
+    FROM extracted, jsonb_tree(extracted.json)
     ORDER BY flds;')
 
     # get all fullkeys and types
@@ -817,21 +817,22 @@ docdb_query.src_sqlite <- function(src, key, query, ...) {
 
     ins <- stringi::stri_extract_all_regex(
       # keep space before \\)"
-      fldQ$queryCondition, paste0("\"\\$.", i, "\"\\) IN \\((.+?) \\)"))[[1]]
+      fldQ$queryCondition, paste0("\"\\$.", i, "\"\\) IN \\((.+?)\\)"))[[1]]
 
     if (!is.na(ins)) {
 
       isString <- grepl("\\('", ins) # "5, 4" or "'a ,b', 'd, f'"
-      # keep space before \\)"
-      ii <- stringi::stri_replace_all_regex(ins, "\"(.+?)\"\\) IN \\((.+?) \\)", "$2")
+      ii <- stringi::stri_replace_all_regex(ins, "\"(.+?)\"\\) IN \\((.+?)\\)", "$2")
       ii <- trimws(ii)
       ii <- stringi::stri_split_regex(ii, ifelse(isString, "', ", ", "))[[1]]
       ii <- stringi::stri_replace_all_regex(ii, "^'|'$", "") # start or end delimiters
-      # strings are compared at their full length, cannot use anchors, see above
-      if (any(is.na(suppressWarnings(as.numeric(ii))))) ii <- paste0('(\\["|,")', ii, '(",|"\\])')
+      # strings to be compared at their full length, because IN is about full elements
+      if (any(is.na(suppressWarnings(as.numeric(ii))))) ii <- paste0('(\\["|,"|^)', ii, '(",|"\\]|$)')
 
       # https://sqlite.org/src/file?filename=ext/misc/regexp.c
       ii <- paste0("\"$.", i, "\") REGEXP '", paste0("(", ii, ")", collapse = "|"), "'")
+      # json_extract(\"db\".json,\"$.fld\") REGEXP '"ABC"|"DEF"'
+
       fldQ$queryCondition <- stringi::stri_replace_all_fixed(
         fldQ$queryCondition, ins, ii, vectorize_all = TRUE
       )
@@ -880,7 +881,7 @@ docdb_query.src_sqlite <- function(src, key, query, ...) {
         WHERE /** fldQ$jsonWhere **/
         LIMIT /** n **/ )
       SELECT DISTINCT LTRIM(fullkey, \'$.\') AS flds
-      FROM extracted, json_tree(extracted.json)
+      FROM extracted, jsonb_tree(extracted.json)
       ORDER BY flds;')
 
       # get all fullkeys and types
@@ -1014,9 +1015,9 @@ docdb_query.src_postgres <- function(src, key, query, ...) {
   for (i in fldQ$queryPaths[fldQ$queryPaths != "_id"]) {
 
     fldQ$queryCondition <- gsub(
-      paste0("(\"", i, "\" [INOTREGXP=!<>']+ .+?)( AND | NOT | OR |\\)*$)"),
+      paste0("(?<![.])(\"", i, "\" [INOTREGXP=!<>']+ .+?)( AND | NOT | OR |\\)*$)"),
       "jsonb_path_exists(json, \'$[*] ? (@.\\1)')\\2", # keep $[*]
-      fldQ$queryCondition)
+      fldQ$queryCondition, perl = TRUE)
 
     # - special case IN
     if (grepl(paste0("\"", i, "\" IN \\("), fldQ$queryCondition)) {
@@ -1257,9 +1258,7 @@ docdb_query.src_duckdb <- function(src, key, query, ...) {
         # since 1.3.0 single quotes [\x27\x22ABC\x22\x27, \x27\x22DEF...
         paste0('(LENGTH(list_filter(json(\'[\' || regexp_replace("', i,
                '"::VARCHAR, \'\\\\[|\\\\]|\\\\x27\', \'\', \'g\') || \']\')::JSON[], ',
-               ifelse(package_version(src$dbver) >= package_version("1.3.0"),
-                      'lambda x : x \\2 \\3 )) > 0) \\4',
-                      'x -> x \\2 \\3 )) > 0) \\4')),
+               'lambda x : x \\2 \\3 )) > 0) \\4'),
         fldQ$queryCondition
       )
 
@@ -1375,57 +1374,35 @@ docdb_query.src_duckdb <- function(src, key, query, ...) {
 
   }
 
+  # - if only root fields to be included, these are in SQL extractFields
+  if (!any(grepl("[.]", fldQ$includeFields))) fldQ$includeFields <- character(0L)
+
 
   # special case: return all fields if listfields != NULL
   if (!is.null(params$listfields)) {
 
-    if (package_version(src$dbver) >= package_version("1.3.0")) {
-
-      statement <- insObj('
+    statement <- insObj('
       WITH extracted AS (
-        SELECT _id
-        /** fldQ$extractFields **/
-        FROM "/** key **/"
-        WHERE /** fldQ$selectCondition **/
-        /** sqlLimit **/ )
-      SELECT DISTINCT regexp_replace(LTRIM(fullkey,
-        \'$.\'), \'\\[[0-9]+\\]\', \'\', \'g\') AS flds
+      SELECT _id
+      /** fldQ$extractFields **/
+      FROM "/** key **/")
+      SELECT DISTINCT json_structure(json) AS json
       FROM extracted
-      AS extracted, json_tree(extracted.json)
-      ORDER BY flds;')
+      WHERE (
+      /** fldQ$selectCondition **/
+    );')
 
-      # get all fullkeys and types
-      fields <- DBI::dbGetQuery(
-        conn = src$con,
-        statement = statement,
-        n = -1L)[["flds"]]
+    fldQ$jqrWhere <- jqFieldNames
 
-    } else {
-
-      statement <- insObj('
-        WITH extracted AS (
-        SELECT _id
-        /** fldQ$extractFields **/
-        FROM "/** key **/")
-        SELECT DISTINCT json_structure(json) AS json
-        FROM extracted
-        WHERE  (
-        /** fldQ$selectCondition **/
-        );')
-
-      fldQ$jqrWhere <- jqFieldNames
-
-      # process
-      fields <- unique(processDbGetQuery(
-        getData = 'paste0(DBI::dbGetQuery(conn = src$con,
+    # process
+    fields <- unique(processDbGetQuery(
+      getData = 'paste0(DBI::dbGetQuery(conn = src$con,
                  statement = statement, n = n)[["json"]], "")',
-        jqrWhere = fldQ$jqrWhere
-      )[["out"]])
-
-    }
+      jqrWhere = fldQ$jqrWhere
+    )[["out"]])
 
     # clean
-    fields <- fields[fields != "_id" & fields != ""]
+    fields <- sort(fields[fields != "_id" & fields != ""])
 
     # return field names
     return(fields)
@@ -1440,9 +1417,9 @@ docdb_query.src_duckdb <- function(src, key, query, ...) {
     FROM "/** key **/" )
     SELECT /** fldQ$selectFields **/
     AS json FROM extracted
-    WHERE  (
+    WHERE (
     /** fldQ$selectCondition **/
-    );')
+  );')
 
   # general processing
   out <- processDbGetQuery(
