@@ -6,7 +6,7 @@ test_that("Source", {
   # unique parameters, see README.Rmd
   dbSrcKey <- function() {
     testKey <- createKey()
-    testSrc <- src_duckdb()
+    testSrc <- suppressWarnings(src_duckdb())
     return(list(testKey = testKey, testSrc = testSrc))
     }
 
@@ -14,7 +14,7 @@ test_that("Source", {
   tmp <- dbSrcKey()
   expect_is(tmp$testSrc, "docdb_src")
   expect_is(tmp$testSrc, "src_duckdb")
-  expect_output(print(tmp$testSrc), "duckdb")
+  expect_output(print(tmp$testSrc), "src: DuckDB")
   duckdb::dbDisconnect(tmp$testSrc$con, shutdown = TRUE)
   rm(tmp)
 
